@@ -1,52 +1,44 @@
-from contextlib import AsyncExitStack
-from lib2to3.pytree import Base
-from typing import List
 import torch
 import torch.nn as nn
 from torch.distributions.categorical import Categorical
 from torch.distributions.normal import Normal
-
-from rlvortex.utils.trainer_utils import v_debug
 from rlvortex.policy.quick_build import init_weights
 
 
-class BaseActor(nn.Module):
+class BaseActorModule(nn.Module):
     def __init__(self, *, net: nn.Module):
         super().__init__()
         self.logits_net = net
 
-    def _distribution(self, obs):
+    def _distribution(self, obs) -> torch.distributions.Distribution:
         raise NotImplementedError
 
-    def _log_prob_from_distribution(self, pi, act):
+    def _log_prob_from_distribution(self, pi, act) -> torch.Tensor:
         raise NotImplementedError
 
 
-class BaseCritic(nn.Module):
+class BaseCriticModule(nn.Module):
     def __init__(self, *, net: nn.Module):
         super().__init__()
         self.v_net = net
 
-    def forward(self, obs):
-        # return torch.squeeze(
-        #     self.v_net(obs), -1
-        # )  # squeeze values from (obs_dim, 1) to (obs_dim,)
+    def forward(self, obs) -> torch.Tensor:
         return self.v_net(obs)
 
 
-class CategoricalActor(BaseActor):
+class CategoricalActor(BaseActorModule):
     def __init__(self, *, net: nn.Module):
         super().__init__(net=net)
 
-    def _distribution(self, obs):
+    def _distribution(self, obs) -> torch.distributions.Distribution:
         logits = self.logits_net(obs)
         return Categorical(logits=logits)
 
-    def _log_prob_from_distribution(self, pi, act):
-        return pi.log_prob(act)
+    def _log_prob_from_distribution(self, pi, act) -> torch.Tensor:
+        return pi.log_prob(act.flatten())
 
 
-class GaussianActor(BaseActor):
+class GaussianActor(BaseActorModule):
     """
     net is the torch neural network module with the first layer fist the environment observation dimension
     init_log_stds is a torch.Tensor with the size of environment action observation
@@ -70,7 +62,7 @@ class GaussianActor(BaseActor):
         return self
 
 
-class GaussianSepActor(BaseActor):
+class GaussianSepActor(BaseActorModule):
     def __init__(
         self,
         *,
@@ -86,9 +78,6 @@ class GaussianSepActor(BaseActor):
         obs_feats = self.preprocess_net(obs)
         mu = self.logits_net(obs_feats)
         std = torch.exp(self.log_std_net(obs_feats))
-        # print(obs_feats, mu, std)
-        # import pdb
-        # pdb.set_trace()
         return Normal(mu, std)
 
     def _log_prob_from_distribution(self, pi, act):
@@ -98,12 +87,12 @@ class GaussianSepActor(BaseActor):
 class BasePPOPolicy(nn.Module):
     def __init__(
         self,
-        actor: BaseActor,
-        critic: BaseCritic,
+        actor: BaseActorModule,
+        critic: BaseCriticModule,
     ) -> None:
         super().__init__()
-        self.actor: BaseActor = actor
-        self.critic: BaseCritic = critic
+        self.actor: BaseActorModule = actor
+        self.critic: BaseCriticModule = critic
         self.actor.apply(init_weights)
         self.critic.apply(init_weights)
 
@@ -146,7 +135,55 @@ class BasePPOPolicy(nn.Module):
         return self
 
 
-import torch.nn.functional as F
+class TestBasePPOPolicy(nn.Module):
+    def __init__(
+        self,
+        actor: BaseActorModule,
+        critic: BaseCriticModule,
+    ) -> None:
+        super().__init__()
+        self.actor: BaseActorModule = actor
+        self.critic: BaseCriticModule = critic
+        self.actor.apply(init_weights)
+        self.critic.apply(init_weights)
+
+    """
+    This method is used to interact with the environment for experience collection. No gradient is computed.
+    """
+
+    def step(self, obs):
+        with torch.no_grad():
+            pi = self.actor._distribution(obs)
+            a = pi.sample()
+            logp_a = self.actor._log_prob_from_distribution(pi, a)
+            v = self.critic(obs).view(-1)
+        return a, {"values": v, "logp_actions": logp_a}
+
+    """
+    This method is used to interact with the environment for evaluation by trained model .
+    """
+
+    def act(self, obs):
+        with torch.no_grad():
+            pi = self.actor._distribution(obs)
+            a = pi.sample()
+        return a
+
+    """
+    This method is used to compute the loss. Graident is computed.
+    """
+
+    def forward(self, observations, actions):
+        pi = self.actor._distribution(observations)
+        logp_a = self.actor._log_prob_from_distribution(pi, actions)
+        v = self.critic(observations).view(-1)
+        entropy = pi.entropy().mean()
+        return logp_a, v, entropy
+
+    def to(self, device):
+        self.actor = self.actor.to(device)
+        self.critic = self.critic.to(device)
+        return self
 
 
 class PenCritic(nn.Module):
@@ -187,12 +224,12 @@ class PenActor(nn.Module):
 class PenPPOPolicy(nn.Module):
     def __init__(
         self,
-        actor: BaseActor,
-        critic: BaseCritic,
+        actor: BaseActorModule,
+        critic: BaseCriticModule,
     ) -> None:
         super().__init__()
-        self.actor: BaseActor = actor
-        self.critic: BaseCritic = critic
+        self.actor: BaseActorModule = actor
+        self.critic: BaseCriticModule = critic
         self.actor.apply(init_weights)
         self.critic.apply(init_weights)
 
