@@ -76,27 +76,15 @@ class NpPPOReplayBuffer(PPOReplayBuffer):
         self.observation_buffer = np.zeros(
             (self.steps_per_env, self.num_envs, *self.observation_dim), dtype=np.float32
         )
-        self.reward_buffer = np.zeros(
-            (self.steps_per_env, self.num_envs), dtype=np.float32
-        )
+        self.reward_buffer = np.zeros((self.steps_per_env, self.num_envs), dtype=np.float32)
         # done_buffer is used to compute the returns and the advantages
-        self.done_buffer = np.zeros(
-            (self.steps_per_env, self.num_envs), dtype=np.float32
-        )
+        self.done_buffer = np.zeros((self.steps_per_env, self.num_envs), dtype=np.float32)
 
         # ppo specific buffer
-        self.advantage_buffer = np.zeros(
-            (self.steps_per_env, self.num_envs), dtype=np.float32
-        )
-        self.return_buffer = np.zeros(
-            (self.steps_per_env, self.num_envs), dtype=np.float32
-        )
-        self.value_buffer = np.zeros(
-            (self.steps_per_env, self.num_envs), dtype=np.float32
-        )
-        self.actions_log_prob_buffer = np.zeros(
-            (self.steps_per_env, self.num_envs), dtype=np.float32
-        )
+        self.advantage_buffer = np.zeros((self.steps_per_env, self.num_envs), dtype=np.float32)
+        self.return_buffer = np.zeros((self.steps_per_env, self.num_envs), dtype=np.float32)
+        self.value_buffer = np.zeros((self.steps_per_env, self.num_envs), dtype=np.float32)
+        self.actions_log_prob_buffer = np.zeros((self.steps_per_env, self.num_envs), dtype=np.float32)
 
     def append_transitions(
         self,
@@ -165,15 +153,9 @@ class NpPPOReplayBuffer(PPOReplayBuffer):
                 dtype=torch.float32,
                 device=device,
             ),
-            torch.as_tensor(
-                self.advantage_buffer.flatten(), dtype=torch.float32, device=device
-            ),
-            torch.as_tensor(
-                self.return_buffer.flatten(), dtype=torch.float32, device=device
-            ),
-            torch.as_tensor(
-                self.value_buffer.flatten(), dtype=torch.float32, device=device
-            ),
+            torch.as_tensor(self.advantage_buffer.flatten(), dtype=torch.float32, device=device),
+            torch.as_tensor(self.return_buffer.flatten(), dtype=torch.float32, device=device),
+            torch.as_tensor(self.value_buffer.flatten(), dtype=torch.float32, device=device),
             torch.as_tensor(
                 self.actions_log_prob_buffer.flatten(),
                 dtype=torch.float32,
